==> notebook-clj-0.0.1.jar: public/cljs-runtime/webly.web.app.js <==
goog.provide('webly.web.app');
goog.require('cljs.core');
goog.require('reagent.dom');
goog.require('taoensso.timbre');
goog.require('re_frame.core');
goog.require('pinkgorilla.ui.config');
goog.require('webly.web.views');
goog.require('webly.config');
pinkgorilla.ui.config.set_prefix_BANG_("/r/");
webly.web.app.print_log_init_BANG_ = (function webly$web$app$print_log_init_BANG_(){
cljs.core.enable_console_print_BANG_();

return taoensso.timbre.set_level_BANG_(new cljs.core.Keyword(null,"timbre-loglevel","timbre-loglevel",1531614940).cljs$core$IFn$_invoke$arity$1(cljs.core.deref(webly.config.webly_config)));
});
webly.web.app.mount_app = (function webly$web$app$mount_app(){
return reagent.dom.render.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [webly.web.views.webly_app], null),document.getElementById("app"));
});
webly.web.app.start = (function webly$web$app$start(routes){
var G__66131 = new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("bidi","init","bidi/init",-1883240046),routes], null);
return (re_frame.core.dispatch_sync.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.dispatch_sync.cljs$core$IFn$_invoke$arity$1(G__66131) : re_frame.core.dispatch_sync.call(null,G__66131));
});
webly.web.app.before_load = (function webly$web$app$before_load(){
cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["shadow-cljs reload: before"], 0));

return taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"webly.web.app","/tmp/form-init2571683730222641663.clj",28,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["shadow-cljs reload: before"], null);
}),null)),null,-1645141128);
});
webly.web.app.after_load = (function webly$web$app$after_load(){
webly.web.app.print_log_init_BANG_();

cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["shadow-cljs reload: after"], 0));

taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"webly.web.app","/tmp/form-init2571683730222641663.clj",34,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["shadow-cljs reload: after"], null);
}),null)),null,-112095977);

cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["clearing reframe subscription cache.."], 0));

(re_frame.core.clear_subscription_cache_BANG_.cljs$core$IFn$_invoke$arity$0 ? re_frame.core.clear_subscription_cache_BANG_.cljs$core$IFn$_invoke$arity$0() : re_frame.core.clear_subscription_cache_BANG_.call(null));

cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["mounting webly-app .."], 0));

return webly.web.app.mount_app();
});
webly.web.app.after_load();

//# sourceMappingURL=webly.web.app.js.map

==> notebook-clj-0.0.2.jar: public/cljs-runtime/webly.web.app.js <==
goog.provide('webly.web.app');
goog.require('cljs.core');
goog.require('reagent.dom');
goog.require('taoensso.timbre');
goog.require('re_frame.core');
goog.require('pinkgorilla.ui.config');
goog.require('webly.web.views');
goog.require('webly.config');
pinkgorilla.ui.config.set_prefix_BANG_("/r/");
webly.web.app.print_log_init_BANG_ = (function webly$web$app$print_log_init_BANG_(){
cljs.core.enable_console_print_BANG_();

return taoensso.timbre.set_level_BANG_(new cljs.core.Keyword(null,"timbre-loglevel","timbre-loglevel",1531614940).cljs$core$IFn$_invoke$arity$1(cljs.core.deref(webly.config.webly_config)));
});
webly.web.app.mount_app = (function webly$web$app$mount_app(){
return reagent.dom.render.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [webly.web.views.webly_app], null),document.getElementById("app"));
});
webly.web.app.start = (function webly$web$app$start(routes){
var G__66899 = new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("bidi","init","bidi/init",-1883240046),routes], null);
return (re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1(G__66899) : re_frame.core.dispatch.call(null,G__66899));
});
webly.web.app.before_load = (function webly$web$app$before_load(){
cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["shadow-cljs reload: before"], 0));

return taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"webly.web.app","/tmp/form-init5480154391856654582.clj",28,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["shadow-cljs reload: before"], null);
}),null)),null,-376638918);
});
webly.web.app.after_load = (function webly$web$app$after_load(){
webly.web.app.print_log_init_BANG_();

cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["shadow-cljs reload: after"], 0));

taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"webly.web.app","/tmp/form-init5480154391856654582.clj",34,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["shadow-cljs reload: after"], null);
}),null)),null,-906394287);

cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["clearing reframe subscription cache.."], 0));

(re_frame.core.clear_subscription_cache_BANG_.cljs$core$IFn$_invoke$arity$0 ? re_frame.core.clear_subscription_cache_BANG_.cljs$core$IFn$_invoke$arity$0() : re_frame.core.clear_subscription_cache_BANG_.call(null));

cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["mounting webly-app .."], 0));

return webly.web.app.mount_app();
});
webly.web.app.after_load();

//# sourceMappingURL=webly.web.app.js.map
